API docs for “spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestAuthenticated”

# Class s.t.w.t.t.JSONRPCTestAuthenticated(JSONRPCTestCase):

Part of spamfighter.txjsonrpc.web.test.test_jsonrpc View Source View In Hierarchy

Test with authenticated proxy. We run this with the same inout/ouput as above.

Method | setUp | Undocumented
Method | testAuthInfoInURL | Undocumented
Method | testExplicitAuthInfo | Undocumented
Method | testExplicitAuthInfoOverride | Undocumented

Inherited from JSONRPCTestCase:

Method | tearDown | Undocumented
Method | proxy | Undocumented
Method | testResults | Undocumented
Method | testErrors | Undocumented

def setUp(self): (source)
overrides spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestCase.setUp
Undocumented
def testAuthInfoInURL(self): (source)
Undocumented
def testExplicitAuthInfo(self): (source)
Undocumented
def testExplicitAuthInfoOverride(self): (source)
Undocumented